==> pyskool-0.2.1.tar.bz2: pyskool-0.2.1/pyskool/animal.py <==
# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

from character import Character
from animatorystates import *
from skool import Location

class Animal(Character):
    def __init__(self, animal_id, tap_id, initial_as, location):
        Character.__init__(self, animal_id, animal_id)
        self.tap_id = tap_id
        self.animatory_state = self.initial_as = initial_as
        self.direction = self.initial_direction = -1

    def get_tap_id(self, lesson_id):
        return self.tap_id

    def is_mouse(self):
        return False

    def is_frog(self):
        return False

    def is_blocked(self, distance=0):
        """Return True if the animal can proceed no further in the current direction, False otherwise."""
        # Check walls and closed doors
        if self.skool.barrier(self, distance):
            return True
        # Check staircases that must be ascended or descended
        staircase = self.skool.staircase(self, distance)
        if staircase and staircase.force:
            return True
        # Check whether there is a floor in front of the animal
        floor = self.skool.floor_at(self.x + self.direction * max(1, distance), self.y)
        return floor is None

    def is_eric_nearby(self):
        eric_x, eric_y = self.get_location_of_eric()
        return self.y == eric_y and abs(self.x - eric_x) <= 3

class Mouse(Animal):
    def __init__(self, mouse_id, tap_id, initial_as, location, immortal=True):
        Animal.__init__(self, mouse_id, tap_id, initial_as, location)
        self.initial_location = Location(location)
        self.x, self.y = location
        self.immortal = immortal

    def is_mouse(self):
        return True

    def is_sitting(self):
        return True

    def scare_people(self):
        self.cast.scare_musophobes(self)

    def die(self):
        self.cast.kill_mouse(self)

class Frog(Animal):
    def __init__(self, frog_id, tap_id, initial_as, release_location):
        Animal.__init__(self, frog_id, tap_id, initial_as, release_location)
        self.x, self.y = -3, 0
        self.initial_location = Location((self.x, self.y))
        self.release_location = release_location
        self.falling = False
        self.trapped = True

    def is_frog(self):
        return True

    def is_sitting(self):
        return self.animatory_state == SIT

    def release(self):
        self.trapped = False
        self.x, self.y = self.release_location

    def insert_into_cup(self, cup):
        self.trapped = True
        self.animatory_state = SIT
        self.x, self.y = cup.x - 1, cup.y - 3

    def fall_from_cup(self, cup):
        cup.remove_frog(self)
        self.trapped = False
        self.falling = True

    def check_heads(self):
        self.cast.check_heads(self)

    def land(self):
        self.falling = False
        self.animatory_state = SIT

==> pyskool-0.2.2.tar.bz2: pyskool-0.2.2/pyskool/animal.py <==
# -*- coding: utf-8 -*-
# Copyright 2010 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of Pyskool.
#
# Pyskool is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# Pyskool is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# Pyskool. If not, see <http://www.gnu.org/licenses/>.

from character import Character
from animatorystates import *
from location import Location

class Animal(Character):
    def __init__(self, animal_id, tap_id, initial_as, location):
        Character.__init__(self, animal_id, animal_id)
        self.x, self.y = location
        self.initial_location = Location(location)
        self.tap_id = tap_id
        self.animatory_state = self.initial_as = initial_as
        self.direction = self.initial_direction = -1

    def get_tap_id(self, lesson_id):
        return self.tap_id

    def is_mouse(self):
        return False

    def is_frog(self):
        return False

    def is_blocked(self, distance=0):
        """Return True if the animal can proceed no further in the current direction, False otherwise."""
        # Check walls and closed doors
        if self.skool.barrier(self, distance):
            return True
        # Check staircases that must be ascended or descended
        staircase = self.skool.staircase(self, distance)
        if staircase and staircase.force:
            return True
        # Check whether there is a floor in front of the animal
        floor = self.skool.floor_at(self.x + self.direction * max(1, distance), self.y)
        return floor is None

    def is_eric_nearby(self):
        eric_x, eric_y = self.get_location_of_eric()
        return self.y == eric_y and abs(self.x - eric_x) <= 3

class Mouse(Animal):
    def __init__(self, mouse_id, tap_id, initial_as, location, immortal=True):
        Animal.__init__(self, mouse_id, tap_id, initial_as, location)
        self.immortal = immortal

    def is_mouse(self):
        return True

    def is_sitting(self):
        return True

    def scare_people(self):
        self.cast.scare_musophobes(self)

    def die(self):
        self.cast.kill_mouse(self)

class Frog(Animal):
    def __init__(self, frog_id, tap_id, initial_as, location):
        Animal.__init__(self, frog_id, tap_id, initial_as, location)
        self.falling = False
        self.trapped = False

    def is_frog(self):
        return True

    def is_sitting(self):
        return self.animatory_state == SIT

    def insert_into_cup(self, cup):
        self.trapped = True
        self.animatory_state = SIT
        self.x, self.y = cup.x - 1, cup.y - 3

    def fall_from_cup(self, cup):
        cup.remove_frog(self)
        self.trapped = False
        self.falling = True

    def check_heads(self):
        return self.cast.check_heads(self)
